Unit Testing — Pootle 2.5.0 documentation

# Unit Testing

Warning

This page needs updating.

This page contains notes about Pootle’s unit tests and how they should be used, interpreted and expanded. You might also want to check the testing guidelines.

Pootle’s unit tests use the Django testing framekwork, and can be executed with:

    $ python manage.py test pootle_app

Although you can run tests for all applications, several of the external applications are not passing their tests which renders this less useful.

These can be run with py.test if you have the correct plugin for py.test installed. More information.